%% Comment all function calls to output every variable to the workspace.
%% Uncomment the following line for no output of variables to the workspace: 
% function linwavetheory()



%% Uncomment the following line to output only H, T, D to the workspace:                                                                                                                                                                                                            
 function [H,T,alpha_deg] = linwavetheory(H0,T,alpha0_deg,dep0,dep);


%!#################################################################################################################################133! ! Fortran 90/95/2003/2008 ISO max = 132
%=======================================================================================% 
%!======================================================================73! F77 ISO=72 !%
%!**********************************************************************73!            !%
%!                                                                                     !%
%!                *****************************************************                !%
%!                *                  linwavetheory.m                  *                !%
%!                *                                                   *                !%
%!                *                                                   *                !%
%!                *   Calculates  Linear wave theory parameters and   *                !%
%!                *  Snell's Law for linear wave angle transformation *                !%
%!                *                   Ken Connell                     *                !%
%!                *                 Rusty Permenter                   *                !%
%!                *                                                   *                !%
%!                *                                                   *                !%
%!                *****************************************************                !%
%!                                                                                     !%
%!                                                                                     !%
%!  Calls:      wavdispeq.m   <k=wavdispeq(T0,d0,g) >                                  !%
%!                                                                                     !%
%!                                                                                     !%
%!                                                                                     !%
%!                                                                                     !%
%!  Inputs:                                                                            !%
%!					 	  T:   Wave Period vector (sec) (row vector [1 x N])                     !%
%!					 	  H0:   Offshore Wave height vector (m) (row vector [1 x N])             !%
%!					 	  d0:   Offshore depth vector (m) (row vector [1 x N])                   !%
%!              g:   Gravitational Acceleration (m/s^2)   (row vector [1 x N])         !%
%!              alpha0_deg: offshore wave angle in degrees relative to shore-normal    !%
%!                                                                                     !%
%!  Outputs:                                                                           !%
%!					 	  k0: wave number for offshore point 1                                   !%
%!					 	  k:  wave number for nearshore point 2                                  !%
%!					 	  L0: wavelength for offshore point 1                                    !%
%!					 	  L:  wavelength for nearshore point 2                                   !%
%!					 	  alpha_deg: nearshore  wave angle in degrees relative to shore-normal   !%
%!					 	  alpha0: offshore wave angle in radians relative to shore-normal        !%
%!					 	  alpha: nearshore wave angle in radians relative to shore-normal        !%
%!					 	  H:   Wave height vector (m) at point 2(row vector [1 x N])             !%
%!                                                                                     !%
%!                                                                                     !%
%!                                                                                     !%
%!**********************************************************************73!            !%
%!======================================================================73! F77 ISO=72 !%
%=======================================================================================% 
%!#################################################################################################################################133! ! Fortran 90/95/2003/2008 ISO max = 132

% Global Parameters:
% TOLERANCE=0.001; % Numerical precision tolerance to reach before exiting while loops
g=9.81; % gravitational acceleration (m/s^2)
           


% example inputs:   
%dep0=200; % Offshore depth (meters) 
%dep=15; % Target Depth (meters)

%alpha0_deg=-15; % Offshore wave angle (degrees, relative to shore normal) 
% alpha0_deg=theta0_deg; % Offshore wave angle (degrees, relative to shore normal) 



%=======================================================================================================
%                              CALCULATIONS
%=======================================================================================================

z=-dep; % position on z-plane--- z=-h is the bottom; z=0 is still water level

% Deep water wave parameters:
% Angular wave frequency:
disp('Angular wave frequency: '),disp('sigma')
sigma = (2.*pi)./T;
% Deep water wave number:
disp('Deep water wave number: '),disp('k0')
k0 = sigma.^ 2./g;
% Deep water wave length:
disp('Deep water wave length: '),disp('L0')
L0 = 2 .* pi ./ k0;

% =====================================================================73!
%         START Deep water/Transitional water/Shallow water Check:
% =====================================================================73!
min_d0 = min(dep0)    
max_L0 = max(L0)
depthcheck=min_d0/max_L0
% Check for deepwater input:
if depthcheck > 0.5
  disp('Ratio of minimum depth (min_d0) to maximum wavelength (max_L0) at the input wave station is greater than 0.5')
  disp(' (i.e., dep0/L0 > 1/2) ')
  disp('Input wave station is classified as "Deep Water"...')   
  disp('Proceeding with calculation...')  
  disp(' ')  
elseif depthcheck < 0.05 
  disp('Ratio of minimum depth (min_d0) to maximum wavelength (max_L0) at the input wave station is less than 0.05 (i.e., dep0/L0 < 1/20)')
  disp(' (i.e., dep0/L0 < 1/20) ')
  disp('Input wave station is classified as "Shallow Water"...')
  continuecalcs = input('Continue with calculations? <Y/[N]>','s');
  if continuecalcs == 'Y' | continuecalcs == 'y'   % uppercase or lowercase YES
    disp('Proceeding with calculation... ')
    disp(' ')
  else
    disp(['You entered ',continuecalcs])
    disp('Terminating calculation... ')
    return
  end
else
  disp('Ratio of minimum depth (min_d0) to maximum wavelength (max_L0) at the input wave station is between  0.5 and 0.05')
  disp('Input wave station is classified as "Transitional Water"...')
  disp(' (i.e., 1/20 < dep0/L0 < 1/2) ')
  disp('Proceeding with calculation...')  
  disp(' ')  
  continuecalcs = input('Continue with calculations? <Y/[N]>','s');
  if continuecalcs == 'Y' | continuecalcs == 'y'   % uppercase or lowercase YES
    disp('Proceeding with calculation... ')
    disp(' ')
  else
    disp(['You entered ',continuecalcs])
    disp('Terminating calculation... ')
    return
  end
end
% =====================================================================73!
%         END Deep water/Transitional water/Shallow water Check:
% =====================================================================73!

% Deep water wave celerity:
disp('Deep water wave celerity: ')
c0=sigma ./ k0;
disp('c0')
% Deep water wave celerity:
disp('Deep water group velocity: '),disp('Cg0')
Cg0 = (0.5) .* c0;

% call wavdispeq.m using input wave period (T), target depth (dep), and gravitation acceleration (g):

% Calculated wave number using dispersion equation:
disp('Calculated wave number at specified target depth, dep: '),disp('k')
k=wavdispeq(T,dep,g); % calls wavdispeq.m to calculate k through the dispersion equation. % k=(2.*pi)./L;  % wave number

% Calculated wave length using dispersion equation:
disp('Calculated wave length at specified target depth, dep: '),disp('L')
L=2.*pi./k; % wave length (meters)

% Calculated wave celerity:
disp('Calculated wave celerity at specified target depth, dep: '),disp('c')
c = sigma ./ k;

n=(1/2).*(1+(2*k.*(dep))./sinh((2.*k.*(dep))));

% Calculated group velocity:
disp('Calculated wave group velocity at specified target depth, dep: '),disp('Cg')
Cg = n .* c;

% =====================================================================73!
%         START Snell's Law:
% =====================================================================73!
% Deep water wave angle (in radians):
alpha0=alpha0_deg.*(pi./180);
% Wave angle at target depth, dep (in radians):
alpha_sin=(c.*sin(alpha0))./c0;  

% Avoid imaginary numbers outside of the [-1:1] domain:
alpha_sin(alpha_sin(1:end) > 1)=1;
alpha_sin(alpha_sin(1:end) < -1) = -1;

alpha2=asin(alpha_sin);

% Wave angle at target depth, dep (converting to degrees):
alpha_deg=(180./pi).*alpha2;
% Wave shoaling coefficient, Ks :
disp('Calculated wave shoaling coefficient, Ks, at specified target depth, dep: '),disp('shoalcoef')
shoalcoef = sqrt(Cg0./Cg);

% Wave Refraction coefficient, Kr :
disp('Calculated wave shoaling coefficient, Kr, at specified target depth, dep: '),disp('refcoef')
refcoef=sqrt(cos(alpha0)./cos(alpha2));

H=H0.*shoalcoef.*refcoef;
% =====================================================================73!
%         END Snell's Law:
% =====================================================================73!

