% Linear Wave theory's dispersion relation
%
% k=wave number (2*Pi/L)
% L=wave length
% sigma=angular frequency (2*Pi*f or 2*Pi/T)
% f=frequency (Hz)
% T=wave period
% h=water depth
% g=gravitational acceleration
% tol= tolerance for convergence

function k=wavdispeq(T,h,g)
tol=1e-10;
sigma=(2.*pi)./T;
k=sigma./sqrt(g.*h);
k1=(sigma.^2./(g.*tanh(k.*h)));
while max(k1) > tol
   k1=sigma.^2-g.*k.*tanh(k.*h);
   k2=-g.*(k.*h.*(1./(cosh(k.*h)).^2)+tanh(k.*h));
   k=k - (k1./k2);
end


